// sync'ed with help_mp-en.h 1.95
// Updates & fixes by pl <p_l@gmx.fr> & n.le gaillart <n@tourmentine.com>
// Original translation by Firebird <firebird@chez.com>

// ========================= Aide MPlayer ===========================

#ifdef HELP_MP_DEFINE_STATIC
static char help_text[]=
"Utilisation:      mplayer [options] [url|rpertoire/]fichier\n"
"\n"
"Options de base:  (liste complte dans la page de man)\n"
" -vo <pil[:pr]>  slectionne le pilote et le priph. vido ('-vo help' pour la liste)\n"
" -ao <pil[:pr]>  slectionne le pilote et le priph. audio ('-ao help' pour la liste)\n"
#ifdef HAVE_VCD
" -vcd <npiste>   lit une piste VCD (Video CD) plutt qu'un fichier\n"
#endif
#ifdef HAVE_LIBCSS
" -dvdauth <pr>   prcise le chemin du lecteur DVD (pour les DVD crypts)\n"
#endif
#ifdef USE_DVDREAD
" -dvd <ntitre>   joue un titre DVD plutt qu'un fichier\n"
" -alang/-slang    slectionne la langue audio/sous-titres (code pays  2 lettres)\n"
#endif
" -ss <temps>      dmarre la lecture  'temps' (temps en secondes ou hh:mm:ss)\n"
" -nosound         ne joue aucun son\n"
" -fs              lecture plein-cran (ou -vm, -zoom, dtails dans la page de man)\n"
" -x <x> -y <y>    rsolution de l'affichage ( utiliser avec -vm ou -zoom)\n"
" -sub <fich>      spcifie les sous-titres  utiliser (cf. -subfps, -subdelay)\n"
" -playlist <fich> spcifie la liste des fichiers  jouer\n"
" -vid x -aid y    spcifie les flux vido (x) et audio (y)  jouer\n"
" -fps x -srate y  options pour changer les frq. vido (x fps) et audio (y Hz)\n"
" -pp <qualit>    active le filtre de postprocessing (dtails dans la page de man)\n"
" -framedrop       saut d'images (pour les machines lentes)\n"
"\n"
"Fonctions au clavier: (liste complte dans la page de man, voir aussi input.conf)\n"
" <- ou ->         + / - 10 secondes\n"
" haut ou bas      + / - 1 minute\n"
" PgUp ou PgDown   + / - de 10 minutes\n"
" < ou >           fichier suivant / prcdent dans la playlist\n"
" p ou ESPACE      pause (presser n'importe quelle touche pour continuer)\n"
" q ou ESC         arrte la lecture et quitte le programme\n"
" + ou -           synchro audio / vido: +/- 0.1 seconde\n"
" o                change l'OSD: rien / barre de recherche / barre rech. + temps\n"
" * ou /           augmente/diminue le volume PCM\n"
" z ou x           synchro des sous-titres: +/- 0.1 seconde\n"
" r ou t           pos. des sous-titres: plus haut/plus bas, voir aussi -vop expand\n"
"\n"
" * * * VOIR LA PAGE MAN POUR LES DETAILS ET LES AUTRES OPTIONS ET TOUCHES (AVANCEES) * * *\n"
"\n";
#endif

// ========================= Messages MPlayer ===========================

// mplayer.c: 

#define MSGTR_Exiting "\nSortie... (%s)\n"
#define MSGTR_Exit_quit "Fin"
#define MSGTR_Exit_eof "Fin du fichier"
#define MSGTR_Exit_error "Erreur fatale"
#define MSGTR_IntBySignal "\nMPlayer interrompu par le signal %d dans le module: %s\n"
#define MSGTR_NoHomeDir "Ne peut trouver rpertoire HOME\n"
#define MSGTR_GetpathProblem "Problme get_path(\"config\")\n"
#define MSGTR_CreatingCfgFile "Cration du fichier de config: %s\n"
#define MSGTR_InvalidVOdriver "Nom du pilote de sortie vido invalide: %s\nUtilisez '-vo help' pour avoir une liste des pilotes disponibles.\n"
#define MSGTR_InvalidAOdriver "Nom du pilote de sortie audio invalide: %s\nUtilisez '-ao help' pour avoir une liste des pilotes disponibles.\n"
#define MSGTR_CopyCodecsConf "Copiez/liez etc/codecs.conf depuis le source de MPlayer vers ~/.mplayer/codecs.conf)\n"
#define MSGTR_BuiltinCodecsConf "Utilisation du codecs.conf intgr par dfaut\n"
#define MSGTR_CantLoadFont "Ne peut charger la police: %s\n"
#define MSGTR_CantLoadSub "Ne peut charger les sous-titres: %s\n"
#define MSGTR_ErrorDVDkey "Erreur avec la cl du DVD.\n"
#define MSGTR_CmdlineDVDkey "La cl DVD demande sera utilise pour le dcryptage.\n"
#define MSGTR_DVDauthOk "La squence d'authentification DVD semble OK.\n"
#define MSGTR_DumpSelectedStreamMissing "dump: FATAL: le flux slectionn est manquant!\n"
#define MSGTR_CantOpenDumpfile "Impossible d'ouvrir le fichier dump.\n"
#define MSGTR_CoreDumped "Core dumped :)\n"
#define MSGTR_FPSnotspecified "FPS non spcifi ou invalide dans l'entte! Utilisez l'option -fps.\n"
#define MSGTR_TryForceAudioFmtStr "Tente de forcer la famille de pilotes %s du codec audio ...\n"
#define MSGTR_CantFindAfmtFallback "Ne peut trouver de codec audio pour la famille de pilotes impose, utilisation d'autres.\n"
#define MSGTR_CantFindAudioCodec "Ne peut trouver de codec pour le format audio 0x%X.\n"
#define MSGTR_TryUpgradeCodecsConfOrRTFM "*** Tentez de mettre  jour %s  partir de etc/codecs.conf\n*** Si ce n'est toujours pas bon, alors lisez DOCS/codecs.html ou DOCS/fr/codecs.html !\n"
#define MSGTR_CouldntInitAudioCodec "Impossible d'initialiser le codec audio -> pas de son\n"
#define MSGTR_TryForceVideoFmtStr "Tente de forcer famille de pilotes %s du codec vido %s ...\n"
#define MSGTR_CantFindVideoCodec "Ne peut trouver codec pour format vido 0x%X.\n"
#define MSGTR_VOincompCodec "Le pilote de sortie vido choisi n'est pas compatible avec ce codec.\n"
#define MSGTR_CannotInitVO "FATAL: Ne peut initialiser le pilote vido.\n"
#define MSGTR_CannotInitAO "Ne peut ouvrir/initialiser le priphrique audio -> aucun son\n"
#define MSGTR_StartPlaying "Dmarre la lecture...\n"

#define MSGTR_SystemTooSlow "\n\n"\
"         ************************************************************\n"\
"         **** Votre systme est trop LENT pour jouer ce fichier! ****\n"\
"         ************************************************************\n\n"\
"Raisons possibles, problmes, solutions:\n"\
"- Le plus courant: pilote _audio_ cass/bogu\n"\
"  - Essayez -ao sdl ou utilisez ALSA 0.5 ou l'mulation OSS d'ALSA 0.9.\n"\
"  - Essayez diffrentes valeurs pour -autosync, 30 est un bon dbut.\n"\
"- Vido lente\n"\
"  - Essayez avec un pilotes -vo diffrent (-vo help pour la liste) ou\n"\
"    essayez avec -framedrop!\n"\
"- CPU lent\n"\
"  - N'essayez pas de lire de gros DVD/DivX sur un CPU lent! essayez -hardframedrop.\n"\
"- Fichier corrompu\n"\
"  - ssayez des mlanges de -nobps -ni -forceidx -mc 0.\n"\
"- Pour jouer depuis un mdia lent (nfs/smb, DVD, VCD, etc.)\n"\
"  - Essayez -cache 8192\n"\
"- Utilisez-vous -cache avec un fichier AVI mal multiplex? \n"\
"  - Essayez avec -nocache\n"\
"Lisez DOCS/video.html et DOCS/sound.html pour les astuces de rglage/acclration.\n"\
"Si rien de tout cela ne rsoud le problme, lisez DOCS/bugreports.html.\n\n"

#define MSGTR_NoGui "MPlayer a t compil SANS support GUI!\n"
#define MSGTR_GuiNeedsX "MPlayer GUI a besoin de X11!\n"
#define MSGTR_Playing "Joue %s\n"
#define MSGTR_NoSound "Audio: aucun son\n"
#define MSGTR_FPSforced "FPS forc  %5.3f  (ftime: %5.3f)\n"
#define MSGTR_CompiledWithRuntimeDetection "Compil avec dtection du CPU  l'excution - ATTENTION, ce n'est pas optimal! Pour de meilleures performances, recompilez MPlayer avec l'option --disable-runtime-cpudetection\n"
#define MSGTR_CompiledWithCPUExtensions "Compil pour CPU x86 avec les extensions:"
#define MSGTR_AvailableVideoOutputPlugins "Plugins de sortie vido disponibles:\n"
#define MSGTR_AvailableVideoOutputDrivers "Pilotes de sortie vido disponibles:\n"
#define MSGTR_AvailableAudioOutputDrivers "Pilotes de sortie audio disponibles::\n"
#define MSGTR_AvailableAudioCodecs "Codecs audio disponibles:\n"
#define MSGTR_AvailableVideoCodecs "Codecs vido disponibles:\n"
#define MSGTR_AvailableAudioFm "\nFamilles/pilotes de codecs audio disponibles (inclus  la compilation):\n"
#define MSGTR_AvailableVideoFm "\nFamilles/pilotes de codecs vido disponibles (inclus  la compilation):\n"
#define MSGTR_AvailableFsType "modes plein cran disponibles:\n"
#define MSGTR_UsingRTCTiming "Utilisation de la synchronisation matrielle par RTC (%ldHz)\n"
#define MSGTR_CannotReadVideoProperties "Vido: ne pas pas lire les proprits\n"
#define MSGTR_NoStreamFound "Pas de flux trouv\n"
#define MSGTR_InitializingAudioCodec "Initialisation des codecs audio...\n"
#define MSGTR_ErrorInitializingVODevice "Erreur  l'ouverture/initialisation de la sortie vido choisie (-vo)!\n"
#define MSGTR_ForcedVideoCodec "Codec vido forc: %s\n"
#define MSGTR_ForcedAudioCodec "Codec audio forc: %s\n"
#define MSGTR_AODescription_AOAuthor "AO: Description: %s\nAO: Auteur: %s\n"
#define MSGTR_AOComment "AO: Commentaire: %s\n"
#define MSGTR_Video_NoVideo "Vido: Pas de vido\n"
#define MSGTR_NotInitializeVOPorVO "\nFATAL: n'a pas pu initialiser les filtres vido (-vop) ou la sortie vido (-vo).\n"
#define MSGTR_Paused "\n  =====  PAUSE  =====\r" // pas plus de 23 caractres (ligne d'tat pour les fichiers audio)
#define MSGTR_PlaylistLoadUnable "\nNe peut pas charger la liste de lecture %s.\n"
#define MSGTR_Exit_SIGILL_RTCpuSel \
"- MPlayer a plant  cause d'une 'Instruction Illgale'.\n"\
"  Il y a peut-tre un bogue dans notre nouveau code de dtection CPU...\n"\
"  Veuillez lire DOCS/bugreports.html\n"
#define MSGTR_Exit_SIGILL \
"- MPlayer a plant  cause d'une 'Instruction Illgale'.\n"\
"  Cela se produit gnralement quand vous le lancez sur un CPU diffrent\n"\
"  de celui pour lequel il a t compil/optimis.\n Vrifiez cela!\n"
#define MSGTR_Exit_SIGSEGV_SIGFPE \
"- MPlayer a plant  cause d'une mauvaise utilisation de CPU/FPU/RAM.\n"\
"  Recompilez MPlayer avec --enable-debug et faites un backtrace 'gdb'\n"\
"  et dsassemblez. Pour les dtails, voir DOCS/bugreports.html#crash.\n"
#define MSGTR_Exit_SIGCRASH \
"- MPlayer a plant. Cela n'aurait pas d arriver.\n"\
"  Il y a peut-tre un bogue dans le code de MPlayer _ou_ dans vos pilotes _ou_ dans votre\n"\
"  version de gcc. Si vous pensez que c'est la faute de MPlayer, merci de lire DOCS/bugreports.html\n"\
"  et d'en suivre les instructions. Nous ne pourrons et ne voudrons pas vous aider  moins que vous\n"\
"  ne fournissiez ces informations en rapportant un bogue possible.\n"


// mencoder.c

#define MSGTR_UsingPass3ControllFile "Utilisation du fichier de contrle de la passe 3\n"
#define MSGTR_MissingFilename "\nNom de fichier manquant.\n\n"
#define MSGTR_CannotOpenFile_Device "Ne peut pas ouvrir le fichier/priph.\n"
#define MSGTR_ErrorDVDAuth "Erreur dans l'authentification du DVD.\n"
#define MSGTR_CannotOpenDemuxer "Ne peut pas ouvrir le dmultiplexeur\n"
#define MSGTR_NoAudioEncoderSelected "\nPas d'encodeur audio (-oac) choisi! Choisissez en un ou utilisez -nosound. Essayez -oac help !\n"
#define MSGTR_NoVideoEncoderSelected "\nPas d'encodeur vido (-ovc) choisi! Choisissez-en un, essayez -ovc help !\n"
#define MSGTR_CannotOpenOutputFile "Ne peut pas ouvrir le fichier de sortie '%s'\n"
#define MSGTR_EncoderOpenFailed "N'a pas pu ouvrir l'encodeur\n"
#define MSGTR_ForcingOutputFourcc "Code fourcc de sortie forc  %x [%.4s]\n"
#define MSGTR_WritingAVIHeader "Ecriture de l'entte AVI...\n"
#define MSGTR_DuplicateFrames "\n%d trame(s) duplique(s) !\n"
#define MSGTR_SkipFrame "\nTrame supprime !\n"
#define MSGTR_ErrorWritingFile "%s: Erreur durant l'criture du fichier.\n"
#define MSGTR_WritingAVIIndex "\nEcriture de l'index AVI...\n"
#define MSGTR_FixupAVIHeader "Correction de l'entte AVI...\n"
#define MSGTR_RecommendedVideoBitrate "Bitrate vido recommand pour %s CD: %d\n"
#define MSGTR_VideoStreamResult "\nFlux vido: %8.3f kbit/s  (%d bps)  taille: %d octets  %5.3f secs  %d trames\n"
#define MSGTR_AudioStreamResult "\nFlux audio: %8.3f kbit/s  (%d bps)  taille: %d octets  %5.3f secs\n"

// cfg-mencoder.h:

#define MSGTR_MEncoderMP3LameHelp "\n\n"\
" vbr=<0-4>     mthode  bitrate variable\n"\
"                0: cbr\n"\
"                1: mt\n"\
"                2: rh (par dfaut)\n"\
"                3: abr\n"\
"                4: mtrh\n"\
"\n"\
" abr           bitrate moyen\n"\
"\n"\
" cbr           bitrate constant\n"\
"               Force galement l'encodage en mode CBR sur les modes ABR prslectionns suivants\n"\
"\n"\
" br=<0-1024>   spcifie le bitrate en kbits (CBR et ABR uniquement)\n"\
"\n"\
" q=<0-9>       qualit (0-plus haut, 9-plus bas) (uniquement pour VBR)\n"\
"\n"\
" aq=<0-9>      qualit algorithmique (0-meilleure/plus lent, 9-pire/plus rapide)\n"\
"\n"\
" ratio=<1-100> rapport de compression\n"\
"\n"\
" vol=<0-10>    dfinit le gain d'entre audio\n"\
"\n"\
" mode=<0-3>    (par dfaut: auto)\n"\
"                0: stereo\n"\
"                1: joint-stereo\n"\
"                2: dualchannel\n"\
"                3: mono\n"\
"\n"\
" padding=<0-2>\n"\
"                0: non\n"\
"                1: tout\n"\
"                2: ajuste\n"\
"\n"\
" fast          acclre l'encodage pour les modes VBR prselectionns suivants,\n"\
"               qualit lgrement infrieure et bitrates plus levs.\n"\
"\n"\
" preset=<valeur> fournit les plus hauts paramtres de qualit possibles.\n"\
"                 medium: encodage VBR, bonne qualit\n"\
"                 (intervalle de bitrate 150-180 kbps)\n"\
"                 standard: encodage VBR, haute qualit\n"\
"                 (intervalle de bitrate 170-210 kbps)\n"\
"                 extreme: encodage VBR, trs haute qualit\n"\
"                 (intervalle de bitrate 200-240 kbps)\n"\
"                 insane: encodage CBR, plus haute qualit prselectionne\n"\
"                 (bitrate 320 kbps)\n"\
"                 <8-320>: encodage ABR au bitrate moyen indiqu en kbps.\n\n"

// open.c, stream.c:
#define MSGTR_CdDevNotfound "Lecteur CD-ROM '%s' non trouv!\n"
#define MSGTR_ErrTrackSelect "Erreur lors du choix de la piste VCD.\n"
#define MSGTR_ReadSTDIN "Lecture depuis stdin...\n"
#define MSGTR_UnableOpenURL "Ne peut ouvrir l'URL: %s\n"
#define MSGTR_ConnToServer "Connect au serveur: %s\n"
#define MSGTR_FileNotFound "Fichier non trouv: '%s'\n"

#define MSGTR_SMBInitError "Ne peut pas initialiser libsmbclient: %d\n"
#define MSGTR_SMBFileNotFound "Ne peut pas ouvrir depuis le rseau: '%s'\n"
#define MSGTR_SMBNotCompiled "MPlayer n'a pas t compil avec le support SMB.\n"

#define MSGTR_CantOpenDVD "Ne peut ouvrir le lecteur DVD: %s\n"
#define MSGTR_DVDwait "Lecture de la structure du disque, veuillez patienter...\n"
#define MSGTR_DVDnumTitles "Il y a %d titres sur ce DVD.\n"
#define MSGTR_DVDinvalidTitle "Numro de titre DVD invalide: %d\n"
#define MSGTR_DVDnumChapters "Il y a %d chapitres sur ce titre DVD.\n"
#define MSGTR_DVDinvalidChapter "Numro de chapitre DVD invalide: %d\n"
#define MSGTR_DVDnumAngles "Il y a %d squences sur ce titre DVD.\n"
#define MSGTR_DVDinvalidAngle "Numro de squence DVD invalide: %d\n"
#define MSGTR_DVDnoIFO "Ne peut ouvrir le fichier IFO pour le titre DVD %d.\n"
#define MSGTR_DVDnoVOBs "Ne peut ouvrir titre VOBS (VTS_%02d_1.VOB).\n"
#define MSGTR_DVDopenOk "DVD ouvert avec succs.\n"

// demuxer.c, demux_*.c:
#define MSGTR_AudioStreamRedefined "ATTENTION: Entte du flux audio %d redfini.\n"
#define MSGTR_VideoStreamRedefined "ATTENTION: Entte du flux vido %d redfini.\n"
#define MSGTR_TooManyAudioInBuffer "\nTrop de paquets audio dans le tampon (%d dans %d octets)\n"
#define MSGTR_TooManyVideoInBuffer "\nTrop de paquets vido dans le tampon (%d dans %d octets)\n"
#define MSGTR_MaybeNI "Peut-tre que vous jouez un flux/fichier mal multiplex, ou que le codec a chou?\n"\
                      "Pour les fichier AVI, essayez de forcer le mode non-entrelac avec l'option -ni.\n"
#define MSGTR_SwitchToNi "\nFichier AVI non entrelac - passage en mode -ni...\n"
#define MSGTR_Detected_XXX_FileFormat "Fichier de type %s dtect.\n"
#define MSGTR_DetectedAudiofile "Fichier audio dtect.\n"
#define MSGTR_NotSystemStream "Pas un flux de type MPEG System... (peut-tre un Flux de Transport?)\n"
#define MSGTR_InvalidMPEGES "Flux MPEG-ES invalide??? Contactez l'auteur, c'est peut-tre un bug :(\n"
#define MSGTR_FormatNotRecognized "========== Dsol, ce format de fichier n'est pas reconnu/support ===========\n"\
                                  "== Si ce fichier est un flux AVI, ASF ou MPEG, merci de contacter l'auteur! ==\n"
#define MSGTR_MissingVideoStream "Aucun flux vido trouv.\n"
#define MSGTR_MissingAudioStream "Aucun flux audio trouv -> pas de son\n"
#define MSGTR_MissingVideoStreamBug "Flux vido manquant!? Contactez l'auteur, c'est peut-tre un bug :(\n"

#define MSGTR_DoesntContainSelectedStream "demux: le fichier ne contient pas le flux audio ou vido slectionn.\n"

#define MSGTR_NI_Forced "Forc"
#define MSGTR_NI_Detected "Dtect"
#define MSGTR_NI_Message "%s format de fichier AVI NON-ENTRELAC.\n"

#define MSGTR_UsingNINI "Utilise le support des fichiers AVI mal multiplexs!\n"
#define MSGTR_CouldntDetFNo "Ne peut dterminer le nombre de trames (pour recherche absolue)\n"
#define MSGTR_CantSeekRawAVI "Ne peut chercher dans un flux AVI brut! (Index requis, essayez l'option -idx!)\n"
#define MSGTR_CantSeekFile "Ne peut chercher dans ce fichier.\n"

#define MSGTR_EncryptedVOB "Fichier VOB crypt (support libcss non compil!) Lire DOCS/cd-dvd.html\n"
#define MSGTR_EncryptedVOBauth "Flux crypt mais vous n'avez pas demand d'authentification !\n"

#define MSGTR_MOVcomprhdr "MOV: Les enttes compresss ne sont pas (encore) supports.\n"
#define MSGTR_MOVvariableFourCC "MOV: ATTENTION: Variable FOURCC dtecte!?\n"
#define MSGTR_MOVtooManyTrk "MOV: ATTENTION: Trop de pistes"
#define MSGTR_FoundAudioStream "==> Flux audio trouv: %d\n"
#define MSGTR_FoundVideoStream "==> Flux vido trouv: %d\n"
#define MSGTR_DetectedTV "TV dtecte! ;-)\n"
#define MSGTR_ErrorOpeningOGGDemuxer "Ne peut pas ouvrir le demuxer ogg\n"
#define MSGTR_ASFSearchingForAudioStream "ASF: recherche du flux audio (id:%d)\n"
#define MSGTR_CannotOpenAudioStream "Ne peut pas ouvrir le flux audio: %s\n"
#define MSGTR_CannotOpenSubtitlesStream "Ne peut pas ouvrir le flux des sous-titres: %s\n"
#define MSGTR_OpeningAudioDemuxerFailed "N'a pas pu ouvrir le demuxer audio: %s\n"
#define MSGTR_OpeningSubtitlesDemuxerFailed "N'a pas pu ouvrir le demuxer de sous-titres: %s\n"
#define MSGTR_TVInputNotSeekable "Impossible de rechercher sur l'entre TV! (cette opration correspondra surement  un changement de chanes ;)\n"
#define MSGTR_DemuxerInfoAlreadyPresent "Info du demuxer %s dj prsentes!\n"
#define MSGTR_ClipInfo "Information sur le clip: \n"

#define MSGTR_LeaveTelecineMode "\ndemux_mpg: seq progressive dtecte, quitte le mode TELECINE 3:2\n"
#define MSGTR_EnterTelecineMode "\ndemux_mpg: 3:2 TELECINE dtect, active les effets telecine inverss. FPS chang en %5.3f!  \n"

// dec_video.c & dec_audio.c:
#define MSGTR_CantOpenCodec "Ne peut ouvrir le codec\n"
#define MSGTR_CantCloseCodec "Ne peut fermer le codec\n"

#define MSGTR_MissingDLLcodec "ERREUR: Ne peut trouver le codec DirectShow ncessaire: %s\n"
#define MSGTR_ACMiniterror "Ne peut charger/initialiser le codec AUDIO Win32/ACM (fichier DLL manquant?)\n"
#define MSGTR_MissingLAVCcodec "Ne peut trouver le codec '%s' de libavcodec...\n"

#define MSGTR_MpegNoSequHdr "MPEG: FATAL: Fin du fichier lors de la recherche d'entte de squence\n"
#define MSGTR_CannotReadMpegSequHdr "FATAL: Ne peut lire l'entte de squence.\n"
#define MSGTR_CannotReadMpegSequHdrEx "FATAL: Ne peut lire l'extension d'entte de squence.\n"
#define MSGTR_BadMpegSequHdr "MPEG: Mauvais entte de squence\n"
#define MSGTR_BadMpegSequHdrEx "MPEG: Mauvaise extension d'entte de squence\n"

#define MSGTR_ShMemAllocFail "Ne peut allouer de mmoire partage\n"
#define MSGTR_CantAllocAudioBuf "Ne peut allouer de tampon de sortie audio\n"

#define MSGTR_UnknownAudio "Format audio inconnu/manquant -> pas de son\n"

#define MSGTR_UsingExternalPP "[PP] Utilisation de filtres de postprocessing externes, max q = %d\n"
#define MSGTR_UsingCodecPP "[PP] Utilisation du postprocessing du codec, max q = %d\n"
#define MSGTR_VideoAttributeNotSupportedByVO_VD "L'attribut vido '%s' n'est pas support par ce vo & ce vd. \n"
#define MSGTR_VideoCodecFamilyNotAvailableStr "Famille de codecs vido demande [%s] (vfm=%s) non disponible (activez-la  la compilation)\n"
#define MSGTR_AudioCodecFamilyNotAvailableStr "Famille de codecs audio demande [%s] (afm=%s) non disponible (activez-la  la compilation)\n"
#define MSGTR_OpeningVideoDecoder "Ouverture du dcodeur vido: [%s] %s\n"
#define MSGTR_OpeningAudioDecoder "Ouverture du dcodeur audio: [%s] %s\n"
#define MSGTR_UninitVideoStr "Dsinitialisation vido: %s  \n"
#define MSGTR_UninitAudioStr "Dsinitialistion audio: %s  \n"
#define MSGTR_VDecoderInitFailed "Echec de l'initialisation du VDecoder :(\n"
#define MSGTR_ADecoderInitFailed "Echec de l'initialisation de l'ADecoder :(\n"
#define MSGTR_ADecoderPreinitFailed "Echec de la pr-initialisation de l'ADecoder :(\n"
#define MSGTR_AllocatingBytesForInputBuffer "dec_audio: allocation de %d bytes comme tampon d'entre\n"
#define MSGTR_AllocatingBytesForOutputBuffer "dec_audio: allocation %d + %d = %d octets comme tampon de sortie\n"

// LIRC:
#define MSGTR_SettingUpLIRC "Mise en place du support LIRC...\n"
#define MSGTR_LIRCdisabled "Vous ne pourrez pas utiliser votre tlcommande\n"
#define MSGTR_LIRCopenfailed "Impossible d'activer le support LIRC.\n"
#define MSGTR_LIRCcfgerr "Impossible de lire le fichier de config de LIRC %s.\n"

// vf.c
#define MSGTR_CouldNotFindVideoFilter "N'a pas pu trouver le filtre vido '%s'\n"
#define MSGTR_CouldNotOpenVideoFilter "N'a pas pu ouvrir le filtre vido '%s'\n"
#define MSGTR_OpeningVideoFilter "Ouverture du filtre vido: "
#define MSGTR_CannotFindColorspace "Ne peut pas trouver d'espace de couleurs commun, mme en utilisant 'scale' :(\n"

// vd.c
#define MSGTR_CodecDidNotSet "VDec: le codec n'a pas dfini sh->disp_w et sh->disp_h, essai de contournement!\n"
#define MSGTR_VoConfigRequest "VDec: requte de configuration du vo - %d x %d (csp prfer: %s)\n"
#define MSGTR_CouldNotFindColorspace "N'a pas pu trouver d'espace de couleur correspondant - nouvel essai avec -vop scale...\n"
#define MSGTR_MovieAspectIsSet "L'aspect du film est %.2f:1 - pr-redimensionnement  l'aspect correct.\n"
#define MSGTR_MovieAspectUndefined "L'aspect du film est indfini - pas de pr-redimensionnement appliqu.\n"

// ====================== messages/boutons GUI ========================

#ifdef HAVE_NEW_GUI

// --- labels ---
#define MSGTR_About " propos ..."
#define MSGTR_FileSelect "Choisir un fichier ..."
#define MSGTR_SubtitleSelect "Choisir un sous-titre ..."
#define MSGTR_OtherSelect "Choisir ..."
#define MSGTR_AudioFileSelect "Choisir une source audio extrieure ..."
#define MSGTR_FontSelect "Choisir une police ..."
#define MSGTR_PlayList "Liste de lecture"
#define MSGTR_Equalizer "Equaliseur"
#define MSGTR_SkinBrowser "Navigateur de skins"
#define MSGTR_Network "Streaming sur le rseau ..."
#define MSGTR_Preferences "Prfrences"
#define MSGTR_OSSPreferences "Configuration du pilote OSS"
#define MSGTR_SDLPreferences "Configuration du pilote SDL"
#define MSGTR_NoMediaOpened "pas de mdia ouvert"
#define MSGTR_VCDTrack "Piste du VCD %d"
#define MSGTR_NoChapter "Pas de chapitre"
#define MSGTR_Chapter "Chapitre %d"
#define MSGTR_NoFileLoaded "Pas de fichier charg"

// --- boutons ---
#define MSGTR_Ok "OK"
#define MSGTR_Cancel "Annuler"
#define MSGTR_Add "Ajouter"
#define MSGTR_Remove "Supprimer"
#define MSGTR_Clear "Effacer"
#define MSGTR_Config "Configurer"
#define MSGTR_ConfigDriver "Configuration du pilote"
#define MSGTR_Browse "Browser"

// --- messages d'erreur ---
#define MSGTR_NEMDB "Dsol, pas assez de mmoire pour le tampon de dessin."
#define MSGTR_NEMFMR "Dsol, pas assez de mmoire pour le rendu des menus."
#define MSGTR_IDFGCVD "Dsol, pas de pilote de sortie vido compatible avec la GUI."
#define MSGTR_NEEDLAVCFAME "Dsol, vous ne pouvez pas jouer de fichier non-MPEG avec votre priphrique DXR3/H+ sans rencodage\nVeuillez activer lavc ou fame dans la bote de configuration DXR3/H+."

// --- messages d'erreurs du chargement de skin ---
#define MSGTR_SKIN_ERRORMESSAGE "[Skin] Erreur  la ligne %d du fichier de config de skin: %s" 
#define MSGTR_SKIN_WARNING1 "[skin] Attention  la ligne %d du fichier de config de skin: Widget trouv mais \"section\" n'a pas t trouv avant (%s)"
#define MSGTR_SKIN_WARNING2 "[skin] Attention  la ligne %d du fichier de config de skin: Widget trouv mais \"subsection\" n'a pas t trouv avant (%s)"
#define MSGTR_SKIN_WARNING3 "[skin] Attention  la ligne %d du fichier de config de skin: cette sous-section n'a pas support ce widget (%s)"
#define MSGTR_SKIN_BITMAP_16bit  "Bitmaps de 16 bits ou moins ne sont pas supports ( %s ).\n"
#define MSGTR_SKIN_BITMAP_FileNotFound  "Fichier non trouv ( %s )\n"
#define MSGTR_SKIN_BITMAP_BMPReadError "Erreur de lecture BMP ( %s )\n"
#define MSGTR_SKIN_BITMAP_TGAReadError "Erreur de lecture TGA ( %s )\n"
#define MSGTR_SKIN_BITMAP_PNGReadError "Erreur de lecture PNG ( %s )\n"
#define MSGTR_SKIN_BITMAP_RLENotSupported "tga compact en RLE non supports ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownFileType "format de fichier inconnu ( %s )\n"
#define MSGTR_SKIN_BITMAP_ConvertError "erreur de conversion de 24 bit  32 bit ( %s )\n"
#define MSGTR_SKIN_BITMAP_UnknownMessage "Message inconnu: %s\n"
#define MSGTR_SKIN_FONT_NotEnoughtMemory "pas assez de mmoire\n"
#define MSGTR_SKIN_FONT_TooManyFontsDeclared "trop de polices dclares\n"
#define MSGTR_SKIN_FONT_FontFileNotFound "fichier de police introuvable\n"
#define MSGTR_SKIN_FONT_FontImageNotFound "fichier d'image de police introuvable\n"
#define MSGTR_SKIN_FONT_NonExistentFontID "identificateur de fonte inexistant ( %s )\n"
#define MSGTR_SKIN_UnknownParameter "paramtre inconnu ( %s )\n"
#define MSGTR_SKINBROWSER_NotEnoughMemory "[Browser de skins] pas assez de mmoire.\n"
#define MSGTR_SKIN_SKINCFG_SkinNotFound "Skin non trouv ( %s ).\n"
#define MSGTR_SKIN_SKINCFG_SkinCfgReadError "Erreur de lecture du fichier de configuration du skin ( %s ).\n"
#define MSGTR_SKIN_LABEL "Skins:"

// --- menus gtk
#define MSGTR_MENU_AboutMPlayer " propos de MPlayer"
#define MSGTR_MENU_Open "Ouvrir ..."
#define MSGTR_MENU_PlayFile "Lire un fichier ..."
#define MSGTR_MENU_PlayVCD "Lire un VCD ..."
#define MSGTR_MENU_PlayDVD "Lire un DVD ..."
#define MSGTR_MENU_PlayURL "Lire une URL ..."
#define MSGTR_MENU_LoadSubtitle "Charger un sous-titre ..."
#define MSGTR_MENU_DropSubtitle "Laisser tomber un sous-titre ..."
#define MSGTR_MENU_LoadExternAudioFile "Chargement d'un fichier audio externe ..."
#define MSGTR_MENU_Playing "En cours de lecture"
#define MSGTR_MENU_Play "Lecture"
#define MSGTR_MENU_Pause "Pause"
#define MSGTR_MENU_Stop "Arrt"
#define MSGTR_MENU_NextStream "Flux suivant"
#define MSGTR_MENU_PrevStream "Flux prcdent"
#define MSGTR_MENU_Size "Taille"
#define MSGTR_MENU_NormalSize "Taille normale"
#define MSGTR_MENU_DoubleSize "Taille double"
#define MSGTR_MENU_FullScreen "Plein cran"
#define MSGTR_MENU_DVD "DVD"
#define MSGTR_MENU_VCD "VCD"
#define MSGTR_MENU_PlayDisc "Lire un disque..."
#define MSGTR_MENU_ShowDVDMenu "Afficher le menu DVD"
#define MSGTR_MENU_Titles "Titres"
#define MSGTR_MENU_Title "Titre %2d"
#define MSGTR_MENU_None "(aucun)"
#define MSGTR_MENU_Chapters "Chapitres"
#define MSGTR_MENU_Chapter "Chapitre %2d"
#define MSGTR_MENU_AudioLanguages "Langues (audio)"
#define MSGTR_MENU_SubtitleLanguages "Langues (sous-titres)"
#define MSGTR_MENU_PlayList "Playlist"
#define MSGTR_MENU_SkinBrowser "Browser de skins"
#define MSGTR_MENU_Preferences "Prfrences"
#define MSGTR_MENU_Exit "Quitter ..."
#define MSGTR_MENU_Mute "Silence"
#define MSGTR_MENU_Original "Original"
#define MSGTR_MENU_AspectRatio "Aspect (ratio)"
#define MSGTR_MENU_AudioTrack "Piste audio"
#define MSGTR_MENU_Track "Piste %d"
#define MSGTR_MENU_VideoTrack "Piste Vido"
  
// --- equalizer
#define MSGTR_EQU_Audio "Audio"
#define MSGTR_EQU_Video "Vido"
#define MSGTR_EQU_Contrast "Contraste: "
#define MSGTR_EQU_Brightness "Luminosit: "
#define MSGTR_EQU_Hue "Hue: "
#define MSGTR_EQU_Saturation "Saturation: "
#define MSGTR_EQU_Front_Left "Avant Gauche"
#define MSGTR_EQU_Front_Right "Avant Droit"
#define MSGTR_EQU_Back_Left "Arrire Gauche"
#define MSGTR_EQU_Back_Right "Arrire Droit"
#define MSGTR_EQU_Center "Centre"
#define MSGTR_EQU_Bass "Basses"
#define MSGTR_EQU_All "Tout"
#define MSGTR_EQU_Channel1 "Canal 1:"
#define MSGTR_EQU_Channel2 "Canal 2:"
#define MSGTR_EQU_Channel3 "Canal 3:"
#define MSGTR_EQU_Channel4 "Canal 4:"
#define MSGTR_EQU_Channel5 "Canal 5:"
#define MSGTR_EQU_Channel6 "Canal 6:"

// --- playlist
#define MSGTR_PLAYLIST_Path "Chemin"
#define MSGTR_PLAYLIST_Selected "Fichiers choisis"
#define MSGTR_PLAYLIST_Files "Fichiers"
#define MSGTR_PLAYLIST_DirectoryTree "Hirarchie des dossiers"

// --- preferences
#define MSGTR_PREFERENCES_Audio "Audio"
#define MSGTR_PREFERENCES_Video "Vido"
#define MSGTR_PREFERENCES_SubtitleOSD "Sous-titre & OSD"
#define MSGTR_PREFERENCES_Codecs "Codecs & demuxer"
#define MSGTR_PREFERENCES_Misc "Divers"

#define MSGTR_PREFERENCES_None "Aucun"
#define MSGTR_PREFERENCES_AvailableDrivers "Pilotes disponibles:"
#define MSGTR_PREFERENCES_DoNotPlaySound "Ne pas jouer le son"
#define MSGTR_PREFERENCES_NormalizeSound "Normaliser le son"
#define MSGTR_PREFERENCES_EnEqualizer "Activer l'qualiseur"
#define MSGTR_PREFERENCES_ExtraStereo "Activer l'extra-stro"
#define MSGTR_PREFERENCES_Coefficient "Coefficient:"
#define MSGTR_PREFERENCES_AudioDelay "Retard audio"
#define MSGTR_PREFERENCES_DoubleBuffer "Activer le double-buffering"
#define MSGTR_PREFERENCES_DirectRender "Activer le rendu direct"
#define MSGTR_PREFERENCES_FrameDrop "Activer le saut de trame"
#define MSGTR_PREFERENCES_HFrameDrop "Activer le saut de trame VIOLENT (dangereux)"
#define MSGTR_PREFERENCES_Flip "Mirroir vertical"
#define MSGTR_PREFERENCES_Panscan "Panscan: "
#define MSGTR_PREFERENCES_OSDTimer "Minuteur et indicateurs"
#define MSGTR_PREFERENCES_OSDProgress "Barres de progression seulement"
#define MSGTR_PREFERENCES_OSDTimerPercentageTotalTime "Minuteur, pourcentage et temps total"
#define MSGTR_PREFERENCES_Subtitle "Sous-titre:"
#define MSGTR_PREFERENCES_SUB_Delay "Delay: "
#define MSGTR_PREFERENCES_SUB_FPS "FPS:"
#define MSGTR_PREFERENCES_SUB_POS "Position: "
#define MSGTR_PREFERENCES_SUB_AutoLoad "Dsactiver le chargement automatique des sous-titres"
#define MSGTR_PREFERENCES_SUB_Unicode "Sous-titre en Unicode"
#define MSGTR_PREFERENCES_SUB_MPSUB "Convertit le sous-titre dans le format MPlayer"
#define MSGTR_PREFERENCES_SUB_SRT "Convertit le sous-titre vers le format SubViewer (SRT) bas sur le temps"
#define MSGTR_PREFERENCES_SUB_Overlap "Bascule le recouvrement des sous-titres"
#define MSGTR_PREFERENCES_Font "Police:"
#define MSGTR_PREFERENCES_FontFactor "Facteur de la police:"
#define MSGTR_PREFERENCES_PostProcess "Activer le postprocessing"
#define MSGTR_PREFERENCES_AutoQuality "Qualit auto.: "
#define MSGTR_PREFERENCES_NI "Utiliser le parseur d'AVI mal multiplexs"
#define MSGTR_PREFERENCES_IDX "Reconstruire l'index, si ncessaire"
#define MSGTR_PREFERENCES_VideoCodecFamily "Famille de codecs vido:"
#define MSGTR_PREFERENCES_AudioCodecFamily "Famille de codecs audio:"
#define MSGTR_PREFERENCES_FRAME_OSD_Level "Niveau OSD"
#define MSGTR_PREFERENCES_FRAME_Subtitle "Sous-titre"
#define MSGTR_PREFERENCES_FRAME_Font "Police"
#define MSGTR_PREFERENCES_FRAME_PostProcess "Postprocessing"
#define MSGTR_PREFERENCES_FRAME_CodecDemuxer "Codec & demuxer"
#define MSGTR_PREFERENCES_FRAME_Cache "Cache"
#define MSGTR_PREFERENCES_FRAME_Misc "Divers"
#define MSGTR_PREFERENCES_OSS_Device "Priphrique:"
#define MSGTR_PREFERENCES_OSS_Mixer "Mixer:"
#define MSGTR_PREFERENCES_SDL_Driver "Pilote:"
#define MSGTR_PREFERENCES_Message "ATTENTION: certaines options requirent un redmarrage de la lecture!"
#define MSGTR_PREFERENCES_DXR3_VENC "Encodeur vido:"
#define MSGTR_PREFERENCES_DXR3_LAVC "Utiliser LAVC (ffmpeg)"
#define MSGTR_PREFERENCES_DXR3_FAME "Utiliser FAME"
#define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
#define MSGTR_PREFERENCES_FontEncoding2 "Langues Europennes Occidentales (ISO-8859-1)"
#define MSGTR_PREFERENCES_FontEncoding3 "Langues Europeenes Occidentales avec Euro (ISO-8859-15)"
#define MSGTR_PREFERENCES_FontEncoding4 "Langues Europeenes Slaves/Centrales (ISO-8859-2)"
#define MSGTR_PREFERENCES_FontEncoding5 "Esperanto, Galicien, Maltais, Turc (ISO-8859-3)"
#define MSGTR_PREFERENCES_FontEncoding6 "Caractres Old Baltic (ISO-8859-4)"
#define MSGTR_PREFERENCES_FontEncoding7 "Cyrillique (ISO-8859-5)"
#define MSGTR_PREFERENCES_FontEncoding8 "Arabe (ISO-8859-6)"
#define MSGTR_PREFERENCES_FontEncoding9 "Grec Moderne (ISO-8859-7)"
#define MSGTR_PREFERENCES_FontEncoding10 "Turc (ISO-8859-9)"
#define MSGTR_PREFERENCES_FontEncoding11 "Balte (ISO-8859-13)"
#define MSGTR_PREFERENCES_FontEncoding12 "Celte (ISO-8859-14)"
#define MSGTR_PREFERENCES_FontEncoding13 "Hebreu (ISO-8859-8)"
#define MSGTR_PREFERENCES_FontEncoding14 "Russe (KOI8-R)"
#define MSGTR_PREFERENCES_FontEncoding15 "Ukrainien, Bilorusse (KOI8-U/RU)"
#define MSGTR_PREFERENCES_FontEncoding16 "Chinois Simplifi (CP936)"
#define MSGTR_PREFERENCES_FontEncoding17 "Chinois Traditionnel (BIG5)"
#define MSGTR_PREFERENCES_FontEncoding18 "Japonais (SHIFT-JIS)"
#define MSGTR_PREFERENCES_FontEncoding19 "Coren (CP949)"
#define MSGTR_PREFERENCES_FontEncoding20 "Thalandais (CP874)"
#define MSGTR_PREFERENCES_FontEncoding21 "Cyrillique Windows (CP1251)"
#define MSGTR_PREFERENCES_FontNoAutoScale "Pas d'agrandissement auto"
#define MSGTR_PREFERENCES_FontPropWidth "Proportionnel  la largeur du film"
#define MSGTR_PREFERENCES_FontPropHeight "Proportionnel  la hauteur du film"
#define MSGTR_PREFERENCES_FontPropDiagonal "Proportionnel  la diagonale du film"
#define MSGTR_PREFERENCES_FontEncoding "Encodage:"
#define MSGTR_PREFERENCES_FontBlur "Flou:"
#define MSGTR_PREFERENCES_FontOutLine "Contour:"
#define MSGTR_PREFERENCES_FontTextScale "Echelle du texte:"
#define MSGTR_PREFERENCES_FontOSDScale "Echelle de l'OSD:"
#define MSGTR_PREFERENCES_Cache "Cache activ/dsactiv"
#define MSGTR_PREFERENCES_LoadFullscreen "Dmarrer en plein cran"
#define MSGTR_PREFERENCES_CacheSize "Taille du cache: "
#define MSGTR_PREFERENCES_XSCREENSAVER "Stopper XScreenSaver"
#define MSGTR_PREFERENCES_PlayBar "Active la barre de lecture"
#define MSGTR_PREFERENCES_AutoSync "AutoSynchro on/off"
#define MSGTR_PREFERENCES_AutoSyncValue "Autosynchro: "
#define MSGTR_PREFERENCES_CDROMDevice "Priphrique CD-ROM:"
#define MSGTR_PREFERENCES_DVDDevice "Priphrique DVD:"
#define MSGTR_PREFERENCES_FPS "FPS du film:"
#define MSGTR_PREFERENCES_ShowVideoWindow "Affiche la fentre vido inactive"

#define MSGTR_ABOUT_UHU "Dveloppement GUI sponsoris par UHU Linux\n"
#define MSGTR_ABOUT_CoreTeam "   Equipe principale MPlayer:\n"
#define MSGTR_ABOUT_AdditionalCoders "   Programmeurs additionnels:\n"
#define MSGTR_ABOUT_MainTesters "   Principaux testeurs:\n"
  
// --- messagebox
#define MSGTR_MSGBOX_LABEL_FatalError "Erreur fatale!"
#define MSGTR_MSGBOX_LABEL_Error "Erreur!"
#define MSGTR_MSGBOX_LABEL_Warning "Attention!"
  
#endif
